==> huaweicloudsdkcloudide-3.0.47-py2.py3-none-any.whl: huaweicloudsdkcloudide/v2/model/list_stacks_by_tag_request.py <==
# coding: utf-8

import pprint
import re

import six





class ListStacksByTagRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'tags': 'list[str]'
    }

    attribute_map = {
        'tags': 'tags'
    }

    def __init__(self, tags=None):
        """ListStacksByTagRequest - a model defined in huaweicloud sdk"""
        
        

        self._tags = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags

    @property
    def tags(self):
        """Gets the tags of this ListStacksByTagRequest.

        技术栈标签。默认为空值，查询全部。 目前可取值 Java,Maven,CPP,Vue,ServiceComb,Blockchain,GO, Node.js,DCN,Quantum,JavaScript,Ruby,Python;可查询多个标签

        :return: The tags of this ListStacksByTagRequest.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ListStacksByTagRequest.

        技术栈标签。默认为空值，查询全部。 目前可取值 Java,Maven,CPP,Vue,ServiceComb,Blockchain,GO, Node.js,DCN,Quantum,JavaScript,Ruby,Python;可查询多个标签

        :param tags: The tags of this ListStacksByTagRequest.
        :type: list[str]
        """
        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListStacksByTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudide-3.0.51-py2.py3-none-any.whl: huaweicloudsdkcloudide/v2/model/list_stacks_by_tag_request.py <==
# coding: utf-8

import re
import six





class ListStacksByTagRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'tags': 'list[str]'
    }

    attribute_map = {
        'tags': 'tags'
    }

    def __init__(self, tags=None):
        """ListStacksByTagRequest - a model defined in huaweicloud sdk"""
        
        

        self._tags = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags

    @property
    def tags(self):
        """Gets the tags of this ListStacksByTagRequest.

        技术栈标签。默认为空值，查询全部。 目前可取值 Java,Maven,CPP,Vue,ServiceComb,Blockchain,GO, Node.js,DCN,Quantum,JavaScript,Ruby,Python;可查询多个标签

        :return: The tags of this ListStacksByTagRequest.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ListStacksByTagRequest.

        技术栈标签。默认为空值，查询全部。 目前可取值 Java,Maven,CPP,Vue,ServiceComb,Blockchain,GO, Node.js,DCN,Quantum,JavaScript,Ruby,Python;可查询多个标签

        :param tags: The tags of this ListStacksByTagRequest.
        :type: list[str]
        """
        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListStacksByTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
